==> nextcloud-app-deck-1%3A1.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/en_GB.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "The card \"%s\" on \"%s\" has reached its due date.",
    "The board \"%s\" has been shared with you by %s." : "The board \"%s\" has been shared with you by %s.",
    "{user} has shared the board %s with you." : "{user} has shared the board %s with you.",
    "Finished" : "Finished",
    "To review" : "To review",
    "Action needed" : "Action needed",
    "Later" : "Later",
    "Done" : "Done",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "Create new board" : "Create new board",
    "Cancel" : "Cancel",
    "File already exists" : "File already exists",
    "Do you want to overwrite it?" : "Do you want to overwrite it?",
    "Filter by tag" : "Filter by tag",
    "Show archived cards" : "Show archived cards",
    "Details" : "Details",
    "Sharing" : "Sharing",
    "Tags" : "Tags",
    "Undo" : "Undo",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "Delete",
    "Add a new stack" : "Add a new stack",
    "Add card" : "Add card",
    "Edit" : "Edit",
    "Due date" : "Due date",
    "Remove due date" : "Remove due date",
    "Description" : "Description",
    "Formatting help" : "Formatting help",
    "Attachments" : "Attachments",
    "Comments" : "Comments",
    "Modified" : "Modified",
    "Created" : "Created",
    "Upload attachment" : "Upload attachment",
    "Save" : "Save",
    "Reply" : "Reply",
    "Update" : "Update",
    "(group)" : "(group)",
    "seconds ago" : "seconds ago",
    "Delete card" : "Delete card",
    "Archived boards" : "Archived boards",
    "Shared boards" : "Shared boards",
    "Settings" : "Settings",
    "New board title" : "New board title",
    "Share" : "Share",
    "Edit board" : "Edit board",
    "Archive board" : "Archive board",
    "Unarchive board" : "Unarchive board",
    "Delete board" : "Delete board",
    "Board details" : "Board details"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/en_GB.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "The card \"%s\" on \"%s\" has reached its due date.",
    "The board \"%s\" has been shared with you by %s." : "The board \"%s\" has been shared with you by %s.",
    "{user} has shared the board %s with you." : "{user} has shared the board %s with you.",
    "Finished" : "Finished",
    "To review" : "To review",
    "Action needed" : "Action needed",
    "Later" : "Later",
    "Done" : "Done",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "Create new board" : "Create new board",
    "Cancel" : "Cancel",
    "File already exists" : "File already exists",
    "Do you want to overwrite it?" : "Do you want to overwrite it?",
    "Filter by tag" : "Filter by tag",
    "Show archived cards" : "Show archived cards",
    "Details" : "Details",
    "Sharing" : "Sharing",
    "Tags" : "Tags",
    "Undo" : "Undo",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Delete" : "Delete",
    "Add a new stack" : "Add a new stack",
    "Add card" : "Add card",
    "Edit" : "Edit",
    "Title" : "Title",
    "Members" : "Members",
    "Due date" : "Due date",
    "Remove due date" : "Remove due date",
    "Description" : "Description",
    "Formatting help" : "Formatting help",
    "Attachments" : "Attachments",
    "Comments" : "Comments",
    "Modified" : "Modified",
    "Created" : "Created",
    "Upload attachment" : "Upload attachment",
    "Save" : "Save",
    "Reply" : "Reply",
    "Update" : "Update",
    "(group)" : "(group)",
    "seconds ago" : "seconds ago",
    "Archive card" : "Archive card",
    "Delete card" : "Delete card",
    "Archived boards" : "Archived boards",
    "Shared with you" : "Shared with you",
    "Settings" : "Settings",
    "New board title" : "New board title",
    "Edit board" : "Edit board",
    "Board details" : "Board details"
},
"nplurals=2; plural=(n != 1);");
